@@ -1,23 +1,19 @@
+from typing import List
 from typing import Optional
 
+from pychromecast import Chromecast
+
 from .controllers import CastController
 from .controllers import get_app
 from .controllers import get_controller
-from .discovery import CastDevice
-from .discovery import get_cast_device_with_ip
-from .discovery import get_cast_device_with_name
-from .discovery import get_cast_devices
+from .discovery import get_cast_with_ip
+from .discovery import get_cast_with_name
+from .discovery import get_casts
 from .error import APIError
 from .error import CastError
 from .stream_info import StreamInfo
 
 
-def discover() -> list:
-    """Perform discovery of devices present on local network, and return result."""
-
-    return [CattDevice(ip_addr=d.ip) for d in get_cast_devices()]
-
-
 class CattDevice:
     def __init__(self, name: str = "", ip_addr: str = "", lazy: bool = False) -> None:
         """
@@ -38,8 +34,7 @@ class CattDevice:
         self.ip_addr = ip_addr
         self.uuid = None
 
-        self._cast_device = None  # type: Optional[CastDevice]
-        # Type comment for compatibility with Py3.5-.
+        self._cast = None  # type: Optional[Chromecast]
         self._cast_controller = None  # type: Optional[CastController]
         if not lazy:
             self._create_cast()
@@ -48,30 +43,27 @@ class CattDevice:
         return "<CattDevice: {}>".format(self.name or self.ip_addr)
 
     def _create_cast(self) -> None:
-        self._cast_device = (
-            get_cast_device_with_ip(self.ip_addr) if self.ip_addr else get_cast_device_with_name(self.name)
-        )
-        if not self._cast_device:
+        self._cast = get_cast_with_ip(self.ip_addr) if self.ip_addr else get_cast_with_name(self.name)
+        if not self._cast:
             raise CastError("Device could not be found")
-        self._cast = self._cast_device.cast
-        self.name = self._cast.name
-        self.ip_addr = self._cast_device.ip
-        self.uuid = self._cast.uuid
-
-        self._cast.wait()
+        self.name = self._cast.cast_info.friendly_name
+        self.ip_addr = self._cast.cast_info.host
+        self.uuid = self._cast.cast_info.uuid
 
     def _create_controller(self) -> None:
         self._cast_controller = get_controller(self._cast, get_app("default"))
 
     @property
     def controller(self):
-        if not self._cast_device:
+        if not self._cast:
             self._create_cast()
         if not self._cast_controller:
             self._create_controller()
         return self._cast_controller
 
-    def play_url(self, url: str, resolve: bool = False, block: bool = False, subtitle_url: str = None) -> None:
+    def play_url(
+        self, url: str, resolve: bool = False, block: bool = False, subtitle_url: str = None, **kwargs
+    ) -> None:
         """
         Initiate playback of content.
 
@@ -88,7 +80,7 @@ class CattDevice:
             stream = StreamInfo(url)
             url = stream.video_url
         self.controller.prep_app()
-        self.controller.play_media_url(url, subtitles=subtitle_url)
+        self.controller.play_media_url(url, subtitles=subtitle_url, **kwargs)
 
         if self.controller.wait_for(["PLAYING"], timeout=10):
             if block:
@@ -167,3 +159,9 @@ class CattDevice:
         """
 
         self.controller.volumedown(delta)
+
+
+def discover() -> List[CattDevice]:
+    """Perform discovery of devices present on local network, and return result."""
+
+    return [CattDevice(ip_addr=c.ip) for c in get_casts()]
